#!/bin/sh

VERSION='20200808001' # R.I.P. Luciano

if [ -f "/etc/samba.patch.version" ]; then
	if [ "$(cat /etc/samba.patch.version)" = "$VERSION" ]; then
      echo "ERROR: Changes have been applied!"
      exit 2
	fi
fi

# Verifica versao pfSense
if [ "$(cat /etc/version)" != "2.4.4-RELEASE" ]; then
	echo "ERROR: You need the pfSense version 2.4.4 to apply this script"
	exit 2
fi

ARCH="$(uname -p)"

ASSUME_ALWAYS_YES=YES
export ASSUME_ALWAYS_YES

#/usr/sbin/pkg bootstrap
#/usr/sbin/pkg update

# Lock packages necessary
LOCK_PKGS="pkg pfSense-2.4.4_3"
for LP in $LOCK_PKGS; do
  /usr/sbin/pkg lock $LP
done

mkdir -p /usr/local/etc/pkg/repos
cat <<EOF > /usr/local/etc/pkg/repos/pf2ad.conf
pf2ad: {
    url: "https://pkg.pf2ad.com/pfsense/2.4.4/amd64/",
    mirror_type: "https",
    enabled: yes
}
EOF

# Remove old samba44
if [ "$(/usr/sbin/pkg info | grep samba44)" ]; then
  /usr/sbin/pkg unlock samba44
  /usr/sbin/pkg remove samba44 ldb
fi

# Remove old downgrade
if [ "$(/usr/sbin/pkg info | grep samba410)" ]; then
  /usr/sbin/pkg unlock samba410
  /usr/sbin/pkg remove samba410 tdb
fi

# Remove old samba48
#if [ "$(/usr/sbin/pkg info | grep samba48)" ]; then
#  /usr/sbin/pkg unlock samba48
#  /usr/sbin/pkg remove samba48 tdb
#fi

/usr/sbin/pkg install readline php72-readline

/usr/sbin/pkg update -f -r pf2ad
/usr/sbin/pkg install -r pf2ad net/samba48 2> /dev/null
/usr/sbin/pkg lock samba48

for LP in $LOCK_PKGS; do
  /usr/sbin/pkg unlock $LP
done

rm -rf /usr/local/etc/pkg/repos/pf2ad.conf
#/usr/sbin/pkg update

mkdir -p /var/db/samba4/winbindd_privileged
chown -R :proxy /var/db/samba4/winbindd_privileged
chmod -R 0750 /var/db/samba4/winbindd_privileged

fetch -o /usr/local/pkg/samba.inc -q "https://pf2ad.com/download.php?key=4a81cbcb4f76175d744b52025ad92dc8dd79d85f&version=2.4.4&file=samba.inc"
fetch -o /usr/local/pkg/samba.xml -q "https://pf2ad.com/download.php?key=4a81cbcb4f76175d744b52025ad92dc8dd79d85f&version=2.4.4&file=samba.xml"
fetch -o /usr/local/www/diag_samba.php -q "https://pf2ad.com/download.php?key=4a81cbcb4f76175d744b52025ad92dc8dd79d85f&version=2.4.4&file=diag_samba.php"

/usr/local/sbin/pfSsh.php <<EOF
\$samba = false;
foreach (\$config['installedpackages']['service'] as \$item) {
  if ('samba' == \$item['name']) {
    \$samba = true;
    break;
  }
}
if (\$samba == false) {
	\$config['installedpackages']['service'][] = array(
	  'name' => 'samba',
	  'rcfile' => 'samba.sh',
	  'executable' => 'smbd',
	  'description' => 'Samba daemon'
  );
}
\$samba = false;
foreach (\$config['installedpackages']['menu'] as \$item) {
  if ('Samba (AD)' == \$item['name']) {
    \$samba = true;
    break;
  }
}
if (\$samba == false) {
  \$config['installedpackages']['menu'][] = array(
    'name' => 'Samba (AD)',
    'section' => 'Services',
    'url' => '/pkg_edit.php?xml=samba.xml'
  );
}
write_config();
exec;
exit
EOF


#/usr/sbin/pkg install -f -r pfSense pfSense-pkg-squid
cd /usr/local/pkg
fetch -o - -q "https://pf2ad.com/download.php?key=4a81cbcb4f76175d744b52025ad92dc8dd79d85f&version=2.4.4&file=samba4-squid.diff" | patch -p0

if [ ! -f "/usr/local/etc/smb4.conf" ]; then
	touch /usr/local/etc/smb4.conf
fi
cp -f /usr/local/bin/ntlm_auth /usr/local/libexec/squid/ntlm_auth

/etc/rc.d/ldconfig restart

echo "$VERSION" > /etc/samba.patch.version


